@@ -24,7 +24,6 @@
 #include "seahorse-common.h"
 
 #include "seahorse-util.h"
-#include "seahorse-widget.h"
 
 #include <gio/gio.h>
 #include <glib/gstdio.h>
@@ -76,8 +75,6 @@ seahorse_util_handle_error (GError **error,
 		widget = GTK_WIDGET (parent);
 	else if (GTK_IS_WINDOW (parent))
 		widget = GTK_WIDGET (parent);
-	else if (SEAHORSE_IS_WIDGET (parent))
-		widget = seahorse_widget_get_toplevel (parent);
 	else
 		g_warning ("unsupported 'parent' argument passed to seahorse_util_handle_error() ");
 
@@ -102,48 +99,22 @@ seahorse_util_error_domain ()
     return q;
 }
 
-/** 
- * seahorse_util_get_date_string:
- * @time: Time value to parse
- *
- * Creates a string representation of @time for use with gpg.
- *
- * Returns: A string representing @time. The returned string should be freed
- * with #g_free when no longer needed.
- **/
-gchar*
-seahorse_util_get_date_string (const time_t time)
-{
-	GDate *created_date;
-	gchar *created_string;
-	
-	if (time == 0)
-		return "0";
-	
-	created_date = g_date_new ();
-	g_date_set_time_t (created_date, time);
-	created_string = g_new (gchar, 11);
-	g_date_strftime (created_string, 11, "%Y-%m-%d", created_date);
-	return created_string;
-}
-
-/** 
+/**
  * seahorse_util_print_fd:
  * @fd: The file descriptor to write to
  * @s:  The data to write
  *
  * Returns: FALSE on error, TRUE on success
- **/
-gboolean 
+ */
+gboolean
 seahorse_util_print_fd (int fd, const char* s)
 {
     /* Guarantee all data is written */
     int r, l = strlen (s);
 
     while (l > 0) {
-     
         r = write (fd, s, l);
-        
+
         if (r == -1) {
             if (errno == EPIPE)
                 return FALSE;
@@ -151,7 +122,7 @@ seahorse_util_print_fd (int fd, const char* s)
                 g_critical ("couldn't write data to socket: %s", strerror (errno));
                 return FALSE;
             }
-            
+
         } else {
             s += r;
             l -= r;
@@ -161,31 +132,28 @@ seahorse_util_print_fd (int fd, const char* s)
     return TRUE;
 }
 
-/** 
+/**
  * seahorse_util_printf_fd:
  * @fd: The file descriptor to write to
  * @fmt: The printf format of the data to write
  * @...: The parameters to insert
  *
  * Returns: TRUE on success, FALSE on error
- **/
-gboolean 
+ */
+gboolean
 seahorse_util_printf_fd (int fd, const char* fmt, ...)
 {
-    gchar* t;
+    g_autofree char *t = NULL;
     va_list ap;
-    gboolean ret;
-    
-    va_start (ap, fmt);    
+
+    va_start (ap, fmt);
     t = g_strdup_vprintf (fmt, ap);
     va_end (ap);
-    
-    ret = seahorse_util_print_fd (fd, t);
-    g_free (t);
-    return ret;
+
+    return seahorse_util_print_fd (fd, t);
 }
 
-/** 
+/**
  * seahorse_util_read_data_block:
  * @buf: A string buffer to write the data to.
  * @input: The input stream to read from.
@@ -197,19 +165,20 @@ seahorse_util_printf_fd (int fd, const char* fmt, ...)
  * Returns: The number of bytes copied.
  */
 guint
-seahorse_util_read_data_block (GString *buf, GInputStream *input, 
-                               const gchar *start, const gchar* end)
+seahorse_util_read_data_block (GString      *buf,
+                               GInputStream *input,
+                               const char   *start,
+                               const char   *end)
 {
-    const gchar *t;
+    const char *t;
     guint copied = 0;
-    gchar ch;
+    char ch;
     gsize read;
-     
+
     /* Look for the beginning */
     t = start;
     while (g_input_stream_read_all (input, &ch, 1, &read, NULL, NULL) && read == 1) {
-        
-        /* Match next char */            
+        /* Match next char */
         if (*t == ch)
             t++;
 
@@ -219,24 +188,23 @@ seahorse_util_read_data_block (GString *buf, GInputStream *input,
             copied += strlen (start);
             break;
         }
-    } 
-    
+    }
+
     /* Look for the end */
     t = end;
     while (g_input_stream_read_all (input, &ch, 1, &read, NULL, NULL) && read == 1) {
-        
         /* Match next char */
         if (*t == ch)
             t++;
-        
+
         buf = g_string_append_c (buf, ch);
         copied++;
-                
+
         /* Did we find the whole string? */
         if (!*t)
             break;
     }
-    
+
     return copied;
 }
 
@@ -267,7 +235,7 @@ seahorse_util_write_file_private (const gchar* filename, const gchar* contents,
  * Returns: if source of k1<k2 it returns -1,
  *          1 will be returned  if k1>k2. If the sources are equal it returns 0
  */
-static gint
+static int
 sort_objects_by_place (GObject *k1,
                        GObject *k2)
 {
@@ -340,19 +308,6 @@ seahorse_util_objects_splice_by_place (GList *objects)
 	return NULL;
 }
 
-/**
- * seahorse_util_string_lower:
- * @s: ASCII string to change
- *
- * The whole ASCII string will be lower cased.
- */
-void        
-seahorse_util_string_lower (gchar *s)
-{
-    for ( ; *s; s++)
-        *s = g_ascii_tolower (*s);
-}
-
 /**
  * seahorse_util_parse_version:
  *
