@@ -18,7 +18,7 @@
  * along with this program; if not, see
  * <http://www.gnu.org/licenses/>.
  */
- 
+
 /**
  * A bunch of miscellaneous utility functions.
  */
@@ -31,40 +31,36 @@
 
 typedef guint64 SeahorseVersion;
 
-gchar*      seahorse_util_get_date_string           (const time_t time);
+#define         SEAHORSE_ERROR                          (seahorse_util_error_domain ())
 
+GQuark          seahorse_util_error_domain              (void);
 
-#define     SEAHORSE_ERROR                      (seahorse_util_error_domain ())
+void            seahorse_util_handle_error              (GError     **error,
+                                                         void        *parent,
+                                                         const char  *description,
+                                                         ...);
 
-GQuark      seahorse_util_error_domain          (void);
+unsigned int    seahorse_util_read_data_block           (GString      *buf,
+                                                         GInputStream *input,
+                                                         const char   *start,
+                                                         const char   *end);
 
-void        seahorse_util_handle_error          (GError **error,
-                                                 gpointer parent,
-                                                 const gchar* description,
-                                                 ...);
+gboolean        seahorse_util_print_fd                  (int         fd,
+                                                         const char *data);
 
-guint       seahorse_util_read_data_block       (GString            *buf, 
-                                                 GInputStream*      input, 
-                                                 const gchar        *start, 
-                                                 const gchar*       end);
+gboolean        seahorse_util_printf_fd                 (int         fd,
+                                                         const char *fmt,
+                                                         ...);
 
-gboolean    seahorse_util_print_fd          (int fd, 
-                                             const char* data);
+gboolean        seahorse_util_write_file_private        (const char  *filename,
+                                                         const char  *contents,
+                                                         GError     **err);
 
-gboolean    seahorse_util_printf_fd         (int fd, 
-                                             const char* data, ...);
+GList *         seahorse_util_objects_sort_by_place     (GList *objects);
 
-gboolean    seahorse_util_write_file_private            (const gchar* filename,
-                                                         const gchar* contents,
-                                                         GError **err);
+GList *         seahorse_util_objects_splice_by_place   (GList *objects);
 
-GList *     seahorse_util_objects_sort_by_place         (GList *objects);
-
-GList *     seahorse_util_objects_splice_by_place       (GList *objects);
-
-void        seahorse_util_string_lower        (gchar *s);
-
-SeahorseVersion seahorse_util_parse_version   (const char *version);
+SeahorseVersion seahorse_util_parse_version             (const char *version);
 
 guint       seahorse_ulong_hash    (gconstpointer v);
 
