@@ -14,15 +14,13 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
 
-#ifndef __SEAHORSE_GPGME_SECRET_DELETER_H__
-#define __SEAHORSE_GPGME_SECRET_DELETER_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -38,5 +36,3 @@ typedef struct _SeahorseGpgmeSecretDeleter SeahorseGpgmeSecretDeleter;
 GType              seahorse_gpgme_secret_deleter_get_type   (void) G_GNUC_CONST;
 
 SeahorseDeleter *  seahorse_gpgme_secret_deleter_new        (SeahorseGpgmeKey *key);
-
-#endif /* __SEAHORSE_GPGME_SECRET_DELETER_H__ */
