@@ -36,28 +36,36 @@
 
 #include <string.h>
 
-enum {
-	PROP_0,
-	PROP_NAME,
-	PROP_LABEL,
-	PROP_DESCRIPTION,
-	PROP_ACTIONS,
-	PROP_LOADED
-};
-
 static SeahorsePgpBackend *pgp_backend = NULL;
 
 struct _SeahorsePgpBackend {
     GObject parent;
 
+    char *gpg_homedir;
+
     SeahorseGpgmeKeyring *keyring;
+    SeahorsePgpSettings *pgp_settings;
     SeahorseDiscovery *discovery;
     SeahorseUnknownSource *unknown;
-    GHashTable *remotes;
+    GListModel *remotes;
     SeahorseActionGroup *actions;
     gboolean loaded;
 };
 
+enum {
+    PROP_0,
+    PROP_GPG_HOMEDIR,
+    N_PROPS,
+
+    /* overridden properties */
+    PROP_NAME,
+    PROP_LABEL,
+    PROP_DESCRIPTION,
+    PROP_ACTIONS,
+    PROP_LOADED
+};
+static GParamSpec *obj_props[N_PROPS] = { NULL, };
+
 static void         seahorse_pgp_backend_iface            (SeahorseBackendIface *iface);
 
 static void         seahorse_pgp_backend_collection_init  (GcrCollectionIface *iface);
@@ -70,61 +78,59 @@ G_DEFINE_TYPE_WITH_CODE (SeahorsePgpBackend, seahorse_pgp_backend, G_TYPE_OBJECT
 static void
 seahorse_pgp_backend_init (SeahorsePgpBackend *self)
 {
-	g_return_if_fail (pgp_backend == NULL);
-	pgp_backend = self;
+    g_return_if_fail (pgp_backend == NULL);
+    pgp_backend = self;
 
-	self->remotes = g_hash_table_new_full (g_str_hash, g_str_equal,
-	                                       g_free, g_object_unref);
-
-	self->actions = seahorse_pgp_backend_actions_instance ();
+    self->pgp_settings = seahorse_pgp_settings_instance ();
+    self->remotes = G_LIST_MODEL (g_list_store_new (SEAHORSE_TYPE_SERVER_SOURCE));
+    self->actions = seahorse_pgp_backend_actions_instance ();
 }
 
 #ifdef WITH_KEYSERVER
 
 static void
-on_settings_keyservers_changed (GSettings *settings,
-                                gchar *key,
-                                gpointer user_data)
+on_settings_keyservers_changed (GSettings  *settings,
+                                const char *key,
+                                gpointer    user_data)
 {
-	SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (user_data);
-	SeahorseServerSource *source;
-	gchar **keyservers;
-	GHashTable *check;
-	const gchar *uri;
-	GHashTableIter iter;
-	guint i;
+    SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (user_data);
+    SeahorsePgpSettings *pgp_settings = SEAHORSE_PGP_SETTINGS (settings);
+    g_auto(GStrv) keyservers = NULL;
+    g_autoptr(GPtrArray) check = NULL;
 
-	check = g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_iter_init (&iter, self->remotes);
-	while (g_hash_table_iter_next (&iter, (gpointer*)&uri, (gpointer*)&source))
-		g_hash_table_replace (check, (gpointer)uri, source);
+    check = g_ptr_array_new_with_free_func (g_free);
+    for (guint i = 0; i < g_list_model_get_n_items (self->remotes); i++) {
+        g_autoptr(SeahorseServerSource) remote = NULL;
+        g_autofree char *uri = NULL;
 
-	/* Load and strip names from keyserver list */
-	keyservers = seahorse_servers_get_uris ();
+        remote = g_list_model_get_item (self->remotes, i);
+        uri = seahorse_place_get_uri (SEAHORSE_PLACE (remote));
+        g_ptr_array_add (check, g_steal_pointer (&uri));
+    }
 
-	for (i = 0; keyservers[i] != NULL; i++) {
-		uri = keyservers[i];
+    /* Load and strip names from keyserver list */
+    keyservers = seahorse_pgp_settings_get_uris (pgp_settings);
 
-		/* If we don't have a keysource then add it */
-		if (!g_hash_table_lookup (self->remotes, uri)) {
-			source = seahorse_server_source_new (uri);
-			if (source != NULL) {
-				seahorse_pgp_backend_add_remote (self, uri, source);
-				g_object_unref (source);
-			}
-		}
+    for (guint i = 0; keyservers[i] != NULL; i++) {
+        const char *uri = keyservers[i];
+        gboolean found;
+        guint index;
 
-		/* Mark this one as present */
-		g_hash_table_remove (check, uri);
-	}
+        found = g_ptr_array_find_with_equal_func (check, uri, g_str_equal, &index);
+        if (found) {
+            /* Mark this one as present */
+            g_ptr_array_remove_index (check, index);
+        } else {
+            /* If we don't have a keysource then add it */
+            seahorse_pgp_backend_add_remote (self, uri, FALSE);
+        }
+    }
 
-	/* Now remove any extras */
-	g_hash_table_iter_init (&iter, check);
-	while (g_hash_table_iter_next (&iter, (gpointer*)&uri, NULL))
-		seahorse_pgp_backend_remove_remote (self, uri);
-
-	g_hash_table_destroy (check);
-	g_strfreev (keyservers);
+    /* Now remove any extras */
+    for (guint i = 0; i < check->len; i++) {
+        const char *uri = g_ptr_array_index (check, i);
+        seahorse_pgp_backend_remove_remote (self, uri);
+    }
 }
 
 #endif /* WITH_KEYSERVER */
@@ -155,23 +161,28 @@ on_place_loaded (GObject       *object,
 static void
 seahorse_pgp_backend_constructed (GObject *obj)
 {
-	SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
+    SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
 
-	G_OBJECT_CLASS (seahorse_pgp_backend_parent_class)->constructed (obj);
+    G_OBJECT_CLASS (seahorse_pgp_backend_parent_class)->constructed (obj);
 
-	self->keyring = seahorse_gpgme_keyring_new ();
-	seahorse_place_load (SEAHORSE_PLACE (self->keyring), NULL, on_place_loaded,
-			     g_object_ref (self));
+    /* First of all: configure the GPG home directory */
+    gpgme_set_engine_info (GPGME_PROTOCOL_OpenPGP, NULL, self->gpg_homedir);
 
-	self->discovery = seahorse_discovery_new ();
-	self->unknown = seahorse_unknown_source_new ();
+    self->keyring = seahorse_gpgme_keyring_new ();
+    seahorse_place_load (SEAHORSE_PLACE (self->keyring), NULL, on_place_loaded,
+                         g_object_ref (self));
+
+    self->discovery = seahorse_discovery_new ();
+    self->unknown = seahorse_unknown_source_new ();
 
 #ifdef WITH_KEYSERVER
-	g_signal_connect (seahorse_pgp_settings_instance (), "changed::keyservers",
-	                  G_CALLBACK (on_settings_keyservers_changed), self);
+    g_signal_connect (self->pgp_settings, "changed::keyservers",
+                      G_CALLBACK (on_settings_keyservers_changed), self);
 
-	/* Initial loading */
-	on_settings_keyservers_changed (G_SETTINGS (seahorse_pgp_settings_instance ()), "keyservers", self);
+    /* Initial loading */
+    on_settings_keyservers_changed (G_SETTINGS (self->pgp_settings),
+                                    "keyservers",
+                                    self);
 #endif
 }
 
@@ -208,70 +219,111 @@ seahorse_pgp_backend_get_loaded (SeahorseBackend *backend)
 	return SEAHORSE_PGP_BACKEND (backend)->loaded;
 }
 
+const char *
+seahorse_pgp_backend_get_gpg_homedir (SeahorsePgpBackend *self)
+{
+    g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), FALSE);
+
+    return self->gpg_homedir;
+}
+
 static void
 seahorse_pgp_backend_get_property (GObject *obj,
                                    guint prop_id,
                                    GValue *value,
                                    GParamSpec *pspec)
 {
-	SeahorseBackend *backend = SEAHORSE_BACKEND (obj);
+    SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
+    SeahorseBackend *backend = SEAHORSE_BACKEND (obj);
 
-	switch (prop_id) {
-	case PROP_NAME:
-		g_value_set_string (value,  seahorse_pgp_backend_get_name (backend));
-		break;
-	case PROP_LABEL:
-		g_value_set_string (value,  seahorse_pgp_backend_get_label (backend));
-		break;
-	case PROP_DESCRIPTION:
-		g_value_set_string (value,  seahorse_pgp_backend_get_description (backend));
-		break;
-	case PROP_ACTIONS:
-		g_value_take_object (value, seahorse_pgp_backend_get_actions (backend));
-		break;
-	case PROP_LOADED:
-		g_value_set_boolean (value, seahorse_pgp_backend_get_loaded (backend));
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
-		break;
-	}
+    switch (prop_id) {
+    case PROP_GPG_HOMEDIR:
+        g_value_set_string (value,  seahorse_pgp_backend_get_gpg_homedir (self));
+        break;
+    case PROP_NAME:
+        g_value_set_string (value,  seahorse_pgp_backend_get_name (backend));
+        break;
+    case PROP_LABEL:
+        g_value_set_string (value,  seahorse_pgp_backend_get_label (backend));
+        break;
+    case PROP_DESCRIPTION:
+        g_value_set_string (value,  seahorse_pgp_backend_get_description (backend));
+        break;
+    case PROP_ACTIONS:
+        g_value_take_object (value, seahorse_pgp_backend_get_actions (backend));
+        break;
+    case PROP_LOADED:
+        g_value_set_boolean (value, seahorse_pgp_backend_get_loaded (backend));
+        break;
+    default:
+        G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
+        break;
+    }
+}
+
+static void
+seahorse_pgp_backend_set_property (GObject      *obj,
+                                   unsigned int  prop_id,
+                                   const GValue *value,
+                                   GParamSpec   *pspec)
+{
+    SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
+
+    switch (prop_id) {
+    case PROP_GPG_HOMEDIR:
+        g_free (self->gpg_homedir);
+        self->gpg_homedir = g_value_dup_string (value);
+        break;
+    default:
+        G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, prop_id, pspec);
+        break;
+    }
 }
 
 static void
 seahorse_pgp_backend_finalize (GObject *obj)
 {
-	SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
+    SeahorsePgpBackend *self = SEAHORSE_PGP_BACKEND (obj);
 
 #ifdef WITH_KEYSERVER
-	g_signal_handlers_disconnect_by_func (seahorse_pgp_settings_instance (),
-	                                      on_settings_keyservers_changed, self);
+    g_signal_handlers_disconnect_by_func (self->pgp_settings,
+                                          on_settings_keyservers_changed, self);
 #endif
 
-	g_clear_object (&self->keyring);
-	g_clear_object (&self->discovery);
-	g_clear_object (&self->unknown);
-	g_hash_table_destroy (self->remotes);
-	g_clear_object (&self->actions);
-	pgp_backend = NULL;
+    g_clear_pointer (&self->gpg_homedir, g_free);
+    g_clear_object (&self->keyring);
+    g_clear_object (&self->discovery);
+    g_clear_object (&self->unknown);
+    g_clear_object (&self->remotes);
+    g_clear_object (&self->actions);
+    pgp_backend = NULL;
 
-	G_OBJECT_CLASS (seahorse_pgp_backend_parent_class)->finalize (obj);
+    G_OBJECT_CLASS (seahorse_pgp_backend_parent_class)->finalize (obj);
 }
 
 static void
 seahorse_pgp_backend_class_init (SeahorsePgpBackendClass *klass)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+    GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	gobject_class->constructed = seahorse_pgp_backend_constructed;
-	gobject_class->finalize = seahorse_pgp_backend_finalize;
-	gobject_class->get_property = seahorse_pgp_backend_get_property;
+    gobject_class->constructed = seahorse_pgp_backend_constructed;
+    gobject_class->finalize = seahorse_pgp_backend_finalize;
+    gobject_class->get_property = seahorse_pgp_backend_get_property;
+    gobject_class->set_property = seahorse_pgp_backend_set_property;
 
-	g_object_class_override_property (gobject_class, PROP_NAME, "name");
-	g_object_class_override_property (gobject_class, PROP_LABEL, "label");
-	g_object_class_override_property (gobject_class, PROP_DESCRIPTION, "description");
-	g_object_class_override_property (gobject_class, PROP_ACTIONS, "actions");
-	g_object_class_override_property (gobject_class, PROP_LOADED, "loaded");
+    obj_props[PROP_GPG_HOMEDIR] =
+        g_param_spec_string ("gpg-homedir", "gpg-homedir", "GPG home directory",
+                             NULL,
+                             G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+    g_object_class_install_properties (gobject_class, N_PROPS, obj_props);
+
+    /* Overridden properties */
+    g_object_class_override_property (gobject_class, PROP_NAME, "name");
+    g_object_class_override_property (gobject_class, PROP_LABEL, "label");
+    g_object_class_override_property (gobject_class, PROP_DESCRIPTION, "description");
+    g_object_class_override_property (gobject_class, PROP_ACTIONS, "actions");
+    g_object_class_override_property (gobject_class, PROP_LOADED, "loaded");
 }
 
 static guint
@@ -331,20 +383,29 @@ seahorse_pgp_backend_get (void)
 	return pgp_backend;
 }
 
+/**
+ * seahorse_pgp_backend_initialize:
+ * @gpg_homedir: (nullable):
+ *
+ * Initializes the PGP backend using the given argument as GNUPGHOME directory.
+ * If @gpg_homedir is %NULL, the default will be used.
+ *
+ * (usually it only makes sense to set this to a nonnull value for tests).
+ */
 void
-seahorse_pgp_backend_initialize (void)
+seahorse_pgp_backend_initialize (const char *gpg_homedir)
 {
-	SeahorsePgpBackend *self;
+    SeahorsePgpBackend *self;
 
-	g_return_if_fail (pgp_backend == NULL);
-	self = g_object_new (SEAHORSE_PGP_TYPE_BACKEND, NULL);
+    g_return_if_fail (pgp_backend == NULL);
+    self = g_object_new (SEAHORSE_PGP_TYPE_BACKEND,
+                         "gpg-homedir", gpg_homedir,
+                         NULL);
 
-	seahorse_backend_register (SEAHORSE_BACKEND (self));
-	g_object_unref (self);
+    seahorse_backend_register (SEAHORSE_BACKEND (self));
+    g_object_unref (self);
 
-	g_return_if_fail (pgp_backend != NULL);
-
-	gpgme_set_engine_info (GPGME_PROTOCOL_OpenPGP, NULL, NULL);
+    g_return_if_fail (pgp_backend != NULL);
 }
 
 SeahorseGpgmeKeyring *
@@ -359,28 +420,25 @@ seahorse_pgp_backend_get_default_keyring (SeahorsePgpBackend *self)
 SeahorsePgpKey *
 seahorse_pgp_backend_get_default_key (SeahorsePgpBackend *self)
 {
-	SeahorsePgpKey *key = NULL;
-	SeahorsePgpSettings *settings;
-	const gchar *keyid;
-	gchar *value;
+    SeahorsePgpKey *key = NULL;
+    g_autofree char *value = NULL;
 
-	self = self ? self : seahorse_pgp_backend_get ();
-	g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
+    self = self ? self : seahorse_pgp_backend_get ();
+    g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
 
-	settings = seahorse_pgp_settings_instance ();
-	if (settings != NULL) {
-		value = seahorse_pgp_settings_get_default_key (settings);
-		if (value != NULL && value[0]) {
-			if (g_str_has_prefix (value, "openpgp:"))
-				keyid = value + strlen ("openpgp:");
-			else
-				keyid = value;
-			key = SEAHORSE_PGP_KEY (seahorse_gpgme_keyring_lookup (self->keyring, keyid));
-		}
-		g_free (value);
-	}
+    value = seahorse_pgp_settings_get_default_key (self->pgp_settings);
+    if (value && *value) {
+        const char *keyid;
 
-	return key;
+        if (g_str_has_prefix (value, "openpgp:"))
+            keyid = value + strlen ("openpgp:");
+        else
+            keyid = value;
+
+        key = SEAHORSE_PGP_KEY (seahorse_gpgme_keyring_lookup (self->keyring, keyid));
+    }
+
+    return key;
 }
 
 #ifdef WITH_KEYSERVER
@@ -394,43 +452,92 @@ seahorse_pgp_backend_get_discovery (SeahorsePgpBackend *self)
 	return self->discovery;
 }
 
+/**
+ * seahorse_pgp_backend_get_remotes:
+ * @self: A #SeahorsePgpBackend
+ *
+ * Returns a list of remotes
+ *
+ * Returns: (transfer none) (element-type SeahorseServerSource):
+ */
+GListModel *
+seahorse_pgp_backend_get_remotes (SeahorsePgpBackend *self)
+{
+    g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
+
+    return self->remotes;
+}
+
 SeahorseServerSource *
 seahorse_pgp_backend_lookup_remote (SeahorsePgpBackend *self,
-                                    const gchar *uri)
+                                    const char         *uri)
 {
-	self = self ? self : seahorse_pgp_backend_get ();
-	g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
+    self = self ? self : seahorse_pgp_backend_get ();
+    g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
 
-	return g_hash_table_lookup (self->remotes, uri);
+    for (guint i = 0; i < g_list_model_get_n_items (self->remotes); i++) {
+        g_autoptr(SeahorseServerSource) ssrc = NULL;
+        g_autofree char *src_uri = NULL;
+
+        ssrc = g_list_model_get_item (self->remotes, i);
+        src_uri = seahorse_place_get_uri (SEAHORSE_PLACE (ssrc));
+
+        if (g_ascii_strcasecmp (uri, src_uri) == 0)
+            return ssrc;
+    }
+
+    return NULL;
 }
 
 void
-seahorse_pgp_backend_add_remote (SeahorsePgpBackend *self,
-                                 const gchar *uri,
-                                 SeahorseServerSource *source)
+seahorse_pgp_backend_add_remote (SeahorsePgpBackend   *self,
+                                 const char           *uri,
+                                 gboolean              persist)
 {
-	self = self ? self : seahorse_pgp_backend_get ();
-	g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
-	g_return_if_fail (uri != NULL);
-	g_return_if_fail (SEAHORSE_IS_SERVER_SOURCE (source));
-	g_return_if_fail (g_hash_table_lookup (self->remotes, uri) == NULL);
+    g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
+    g_return_if_fail (seahorse_pgp_backend_lookup_remote (self, uri) == NULL);
 
-	g_hash_table_insert (self->remotes, g_strdup (uri), g_object_ref (source));
+    if (persist) {
+        /* Add to the PGP settings. That's all we need to do, since we're
+         * subscribed to the "changed" callback */
+        seahorse_pgp_settings_add_keyserver (self->pgp_settings, uri, NULL);
+    } else {
+        /* Don't persist, so just immediately create a ServerSource */
+        g_autoptr(SeahorseServerSource) ssrc = NULL;
+        ssrc = seahorse_server_category_create_server (uri);
+        /* If the scheme of the uri is ldap, but ldap support is disabled
+         * in the build, ssrc will be NULL. */
+        if (ssrc)
+            g_list_store_append (G_LIST_STORE (self->remotes), ssrc);
+    }
 }
 
 void
 seahorse_pgp_backend_remove_remote (SeahorsePgpBackend *self,
-                                    const gchar *uri)
+                                    const char         *uri)
 {
-	self = self ? self : seahorse_pgp_backend_get ();
-	g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
-	g_return_if_fail (uri != NULL);
+    self = self ? self : seahorse_pgp_backend_get ();
+    g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
+    g_return_if_fail (uri && *uri);
 
-	g_hash_table_remove (self->remotes, uri);
+    g_debug ("Removing remote %s", uri);
+
+    for (guint i = 0; i < g_list_model_get_n_items (self->remotes); i++) {
+        g_autoptr(SeahorseServerSource) ssrc = NULL;
+        g_autofree char *src_uri = NULL;
+
+        ssrc = g_list_model_get_item (self->remotes, i);
+        src_uri = seahorse_place_get_uri (SEAHORSE_PLACE (ssrc));
+
+        if (g_ascii_strcasecmp (uri, src_uri) == 0)
+            g_list_store_remove (G_LIST_STORE (self->remotes), i);
+    }
+
+    seahorse_pgp_settings_remove_keyserver (self->pgp_settings, uri);
 }
 
 typedef struct {
-    gint num_searches;
+    int num_searches;
 } search_remote_closure;
 
 static void
@@ -475,20 +582,17 @@ seahorse_pgp_backend_search_remote_async (SeahorsePgpBackend *self,
 {
     search_remote_closure *closure;
     g_autoptr(GTask) task = NULL;
-    SeahorseServerSource *source;
     g_autoptr(GHashTable) servers = NULL;
-    GHashTableIter iter;
     g_auto(GStrv) names = NULL;
-    guint i;
 
     self = self ? self : seahorse_pgp_backend_get ();
     g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
 
     /* Get a list of all selected key servers */
-    names = g_settings_get_strv (G_SETTINGS (seahorse_app_settings_instance ()), "last-search-servers");
+    names = seahorse_app_settings_get_last_search_servers (seahorse_app_settings_instance ());
     if (names != NULL && names[0] != NULL) {
         servers = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-        for (i = 0; names[i] != NULL; i++)
+        for (guint i = 0; names[i] != NULL; i++)
             g_hash_table_insert (servers, g_strdup (names[i]), GINT_TO_POINTER (TRUE));
     }
 
@@ -496,17 +600,19 @@ seahorse_pgp_backend_search_remote_async (SeahorsePgpBackend *self,
     closure = g_new0 (search_remote_closure, 1);
     g_task_set_task_data (task, closure, search_remote_closure_free);
 
-    g_hash_table_iter_init (&iter, self->remotes);
-    while (g_hash_table_iter_next (&iter, NULL, (gpointer *)&source)) {
+    for (guint i = 0; i < g_list_model_get_n_items (self->remotes); i++) {
+        g_autoptr(SeahorseServerSource) ssrc = NULL;
+
+        ssrc = g_list_model_get_item (self->remotes, i);
         if (servers) {
-            g_autofree gchar *uri = NULL;
-            g_object_get (source, "uri", &uri, NULL);
-            if (!g_hash_table_lookup (servers, uri))
+            g_autofree char *src_uri = NULL;
+            src_uri = seahorse_place_get_uri (SEAHORSE_PLACE (ssrc));
+            if (!g_hash_table_lookup (servers, src_uri))
                 continue;
         }
 
         seahorse_progress_prep_and_begin (cancellable, GINT_TO_POINTER (closure->num_searches), NULL);
-        seahorse_server_source_search_async (source, search, results, cancellable,
+        seahorse_server_source_search_async (ssrc, search, results, cancellable,
                                              on_source_search_ready, g_object_ref (task));
         closure->num_searches++;
     }
@@ -527,7 +633,7 @@ seahorse_pgp_backend_search_remote_finish (SeahorsePgpBackend *self,
 }
 
 typedef struct {
-    gint num_transfers;
+    int num_transfers;
 } transfer_closure;
 
 static void
@@ -637,8 +743,6 @@ seahorse_pgp_backend_retrieve_async (SeahorsePgpBackend *self,
 {
     transfer_closure *closure;
     g_autoptr(GTask) task = NULL;
-    SeahorsePlace *place;
-    GHashTableIter iter;
 
     g_return_if_fail (SEAHORSE_PGP_IS_BACKEND (self));
     g_return_if_fail (SEAHORSE_IS_PLACE (to));
@@ -647,13 +751,15 @@ seahorse_pgp_backend_retrieve_async (SeahorsePgpBackend *self,
     closure = g_new0 (transfer_closure, 1);
     g_task_set_task_data (task, closure, transfer_closure_free);
 
-    g_hash_table_iter_init (&iter, self->remotes);
-    while (g_hash_table_iter_next (&iter, NULL, (gpointer *)&place)) {
+    for (guint i = 0; i < g_list_model_get_n_items (self->remotes); i++) {
+        g_autoptr(SeahorseServerSource) ssrc = NULL;
+
+        ssrc = g_list_model_get_item (self->remotes, i);
+
         /* Start a new transfer operation between the two places */
         seahorse_progress_prep_and_begin (cancellable,
                                           GINT_TO_POINTER (closure->num_transfers), NULL);
-        seahorse_transfer_keyids_async (SEAHORSE_SERVER_SOURCE (place),
-                                        to, keyids, cancellable,
+        seahorse_transfer_keyids_async (ssrc, to, keyids, cancellable,
                                         on_source_transfer_ready, g_object_ref (task));
         closure->num_transfers++;
     }
@@ -684,7 +790,7 @@ seahorse_pgp_backend_discover_keys (SeahorsePgpBackend *self,
     SeahorseGpgmeKey *key;
     SeahorseObject *object;
     g_autoptr(GPtrArray) todiscover = NULL;
-    gint i;
+    int i;
 
     self = self ? self : seahorse_pgp_backend_get ();
     g_return_val_if_fail (SEAHORSE_PGP_IS_BACKEND (self), NULL);
